Jamo: Hangul Character Analysis
===============================

.. image:: https://travis-ci.org/JDong820/python-jamo.svg?branch=master
    :target: https://travis-ci.org/JDong820/python-jamo
    
.. image:: https://readthedocs.org/projects/python-jamo/badge/?version=latest
    :target: https://readthedocs.org/projects/python-jamo/?badge=latest

Python-jamo is a Python Hangul syllable decomposition and sythesis library
for working with Hangul characters and jamo (U+11xx).

Currently in early release, only modern Hangul is currently supported
(no U+317x, ㆀ, ㆄ, or other archaic stuff).
Support for archaic Hangul will probably be added in the future.

Originally designed to help students identify difficult-to-spell words
containing (ㅔ,ㅐ) or (ㅗ,ㅜ), this project hopes to fill the niche of Korean
phonetic and spelling analysis.


Installation
------------

To install Jamo from `pypi <https://pypi.python.org/pypi/jamo>`_, simply:

.. code-block:: bash

   $ pip install jamo


Documentation
-------------

Documentation is available at
`ReadTheDocs <http://python-jamo.readthedocs.org/ko/latest/>`_.
Documentation in Korean soon.


Contributing
------------

Like this project or want to help? I'm an active github-er, and will review
pulls. I'm open to email as well, so please contact me if you have any ideas
for this project.


License
-------

Apache 2.0
